# sockio

A concurrency agnostic socket library on python.

So far implemented REQ-REP semantics.

Implementations for:

* classic blocking API
* future based API
* asyncio

Join the party by bringing your own concurrency library with a PR!

I am looking in particular for implementations over trio and curio.

## Installation

From within your favourite python environment:

```console
pip install sockio
```


